@@ -159,7 +159,7 @@ void ClosedSCRC(int *ichain, double *mu0, double *sigma2_mu0, double *beta, doub
     arate[j]=0.0;
   }
   
-  double indbase[*ncolBasis];
+  double indbase[*ncolBasis ? *ncolBasis : 1];
   for(j=0; j< *ncolBasis; j++){
     indbase[j]=0.0;
   }
